"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from enum import Enum
from fermisdk import errors, models, utils
from fermisdk._hooks import HookContext
from fermisdk.types import OptionalNullable, UNSET
from fermisdk.utils import get_security_from_env
from fermisdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional


class PerformVisualizationAcceptEnum(str, Enum):
    APPLICATION_JSON = "application/json"
    TEXT_HTML = "text/html"


class Brain(BaseSDK):
    r"""Knowledge graph visualization endpoints"""

    def perform_visualization(
        self,
        *,
        action: models.VisualizationRequestAction,
        connection_ids: Optional[List[str]] = None,
        connection_id: Optional[str] = None,
        discover_external_relationships: Optional[bool] = True,
        confidence_threshold: Optional[models.ConfidenceThreshold] = "high",
        response_format: Optional[models.ResponseFormat] = "html",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        accept_header_override: Optional[PerformVisualizationAcceptEnum] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PerformVisualizationResponse:
        r"""Perform Action API – Visualization

        Trigger unified graph rendering. Supports legacy connection_id and preferred connection_ids. If no connections are provided, returns the base Neo4j schema. Discovers external relationships between connections when enabled.

        :param action: Must be 'visualization'
        :param connection_ids: Multiple connections to merge (preferred)
        :param connection_id: Legacy single-connection input
        :param discover_external_relationships: Enable LLM-based cross-connection edges
        :param confidence_threshold: Confidence level for external relationship filtering
        :param response_format: Response format: 'html' returns PyVis HTML, 'json' returns MongoDB schema-style JSON
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.VisualizationRequest(
            action=action,
            connection_ids=connection_ids,
            connection_id=connection_id,
            discover_external_relationships=discover_external_relationships,
            confidence_threshold=confidence_threshold,
            response_format=response_format,
        )

        req = self._build_request(
            method="POST",
            path="/analytics/perform/action",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value=accept_header_override.value
            if accept_header_override is not None
            else "application/json;q=1, text/html;q=0",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.VisualizationRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="performVisualization",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "text/html"):
            return http_res.text
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VisualizationResponseJSON, http_res)
        if utils.match_response(http_res, ["400", "404"], "application/json"):
            response_data = unmarshal_json_response(errors.ErrorData, http_res)
            raise errors.Error(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorData, http_res)
            raise errors.Error(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FermisdkDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FermisdkDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FermisdkDefaultError("Unexpected response received", http_res)

    async def perform_visualization_async(
        self,
        *,
        action: models.VisualizationRequestAction,
        connection_ids: Optional[List[str]] = None,
        connection_id: Optional[str] = None,
        discover_external_relationships: Optional[bool] = True,
        confidence_threshold: Optional[models.ConfidenceThreshold] = "high",
        response_format: Optional[models.ResponseFormat] = "html",
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        accept_header_override: Optional[PerformVisualizationAcceptEnum] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PerformVisualizationResponse:
        r"""Perform Action API – Visualization

        Trigger unified graph rendering. Supports legacy connection_id and preferred connection_ids. If no connections are provided, returns the base Neo4j schema. Discovers external relationships between connections when enabled.

        :param action: Must be 'visualization'
        :param connection_ids: Multiple connections to merge (preferred)
        :param connection_id: Legacy single-connection input
        :param discover_external_relationships: Enable LLM-based cross-connection edges
        :param confidence_threshold: Confidence level for external relationship filtering
        :param response_format: Response format: 'html' returns PyVis HTML, 'json' returns MongoDB schema-style JSON
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param accept_header_override: Override the default accept header for this method
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.VisualizationRequest(
            action=action,
            connection_ids=connection_ids,
            connection_id=connection_id,
            discover_external_relationships=discover_external_relationships,
            confidence_threshold=confidence_threshold,
            response_format=response_format,
        )

        req = self._build_request_async(
            method="POST",
            path="/analytics/perform/action",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value=accept_header_override.value
            if accept_header_override is not None
            else "application/json;q=1, text/html;q=0",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.VisualizationRequest
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="performVisualization",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "404", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "text/html"):
            return http_res.text
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.VisualizationResponseJSON, http_res)
        if utils.match_response(http_res, ["400", "404"], "application/json"):
            response_data = unmarshal_json_response(errors.ErrorData, http_res)
            raise errors.Error(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorData, http_res)
            raise errors.Error(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FermisdkDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FermisdkDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FermisdkDefaultError("Unexpected response received", http_res)
