"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from fermisdk.utils import FieldMetadata, QueryParamMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class GetConnectionMetadataRequestTypedDict(TypedDict):
    connection_id: str
    r"""Connection ID"""
    provider_config_key: str
    r"""Provider config key"""


class GetConnectionMetadataRequest(BaseModel):
    connection_id: Annotated[
        str,
        pydantic.Field(alias="connectionId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]
    r"""Connection ID"""

    provider_config_key: Annotated[
        str,
        pydantic.Field(alias="providerConfigKey"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]
    r"""Provider config key"""
