"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from fermisdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SessionSummaryTypedDict(TypedDict):
    session_id: NotRequired[str]
    title: NotRequired[Nullable[str]]
    status: NotRequired[Nullable[str]]
    conversation_type: NotRequired[Nullable[str]]
    created_at: NotRequired[Nullable[datetime]]
    updated_at: NotRequired[Nullable[datetime]]
    last_message_at: NotRequired[Nullable[datetime]]
    message_count: NotRequired[Nullable[int]]
    last_message_preview: NotRequired[Nullable[str]]


class SessionSummary(BaseModel):
    session_id: Optional[str] = None

    title: OptionalNullable[str] = UNSET

    status: OptionalNullable[str] = UNSET

    conversation_type: OptionalNullable[str] = UNSET

    created_at: OptionalNullable[datetime] = UNSET

    updated_at: OptionalNullable[datetime] = UNSET

    last_message_at: OptionalNullable[datetime] = UNSET

    message_count: OptionalNullable[int] = UNSET

    last_message_preview: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "session_id",
            "title",
            "status",
            "conversation_type",
            "created_at",
            "updated_at",
            "last_message_at",
            "message_count",
            "last_message_preview",
        ]
        nullable_fields = [
            "title",
            "status",
            "conversation_type",
            "created_at",
            "updated_at",
            "last_message_at",
            "message_count",
            "last_message_preview",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
