"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


Type = Literal[
    "text",
    "markdown",
]


class ChatContentTypedDict(TypedDict):
    type: NotRequired[Type]
    text: NotRequired[str]
    markdown: NotRequired[str]


class ChatContent(BaseModel):
    type: Optional[Type] = None

    text: Optional[str] = None

    markdown: Optional[str] = None
