"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChatSourceTypedDict(TypedDict):
    file_name: NotRequired[str]


class ChatSource(BaseModel):
    file_name: Optional[str] = None
