"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .connection import Connection, ConnectionTypedDict
from fermisdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ConnectionListTypedDict(TypedDict):
    connections: NotRequired[List[ConnectionTypedDict]]


class ConnectionList(BaseModel):
    connections: Optional[List[Connection]] = None
