"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SessionActionResponseTypedDict(TypedDict):
    success: NotRequired[bool]
    action: NotRequired[str]
    session_id: NotRequired[str]
    tenant_id: NotRequired[str]
    user_id: NotRequired[str]
    deleted_count: NotRequired[int]
    message: NotRequired[str]
    error: NotRequired[Nullable[str]]


class SessionActionResponse(BaseModel):
    success: Optional[bool] = None

    action: Optional[str] = None

    session_id: Optional[str] = None

    tenant_id: Optional[str] = None

    user_id: Optional[str] = None

    deleted_count: Optional[int] = None

    message: Optional[str] = None

    error: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "success",
            "action",
            "session_id",
            "tenant_id",
            "user_id",
            "deleted_count",
            "message",
            "error",
        ]
        nullable_fields = ["error"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
