"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectionMetadataRequestMetadataTypedDict(TypedDict):
    pass


class ConnectionMetadataRequestMetadata(BaseModel):
    pass


class ConnectionMetadataRequestTypedDict(TypedDict):
    connection_id: str
    provider_config_key: str
    metadata: NotRequired[ConnectionMetadataRequestMetadataTypedDict]


class ConnectionMetadataRequest(BaseModel):
    connection_id: Annotated[str, pydantic.Field(alias="connectionId")]

    provider_config_key: Annotated[str, pydantic.Field(alias="providerConfigKey")]

    metadata: Optional[ConnectionMetadataRequestMetadata] = None
