"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TestConnectionResponseTypedDict(TypedDict):
    __test__ = False  # pyright: ignore[reportGeneralTypeIssues]

    success: NotRequired[bool]
    message: NotRequired[str]


class TestConnectionResponse(BaseModel):
    __test__ = False

    success: Optional[bool] = None

    message: Optional[str] = None
