"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
import pydantic
from typing import Literal
from typing_extensions import Annotated, TypedDict


DatabaseMetadataRequestDatabaseType = Literal["mongodb",]


class DatabaseMetadataRequestTypedDict(TypedDict):
    connection_string: str
    r"""MongoDB connection string"""
    database_type: DatabaseMetadataRequestDatabaseType


class DatabaseMetadataRequest(BaseModel):
    connection_string: Annotated[str, pydantic.Field(alias="connectionString")]
    r"""MongoDB connection string"""

    database_type: Annotated[
        DatabaseMetadataRequestDatabaseType, pydantic.Field(alias="databaseType")
    ]
