"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatsource import ChatSource, ChatSourceTypedDict
from fermisdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ChatSourcesTypedDict(TypedDict):
    sources_cited: NotRequired[List[ChatSourceTypedDict]]
    sources_searched: NotRequired[List[ChatSourceTypedDict]]


class ChatSources(BaseModel):
    sources_cited: Optional[List[ChatSource]] = None

    sources_searched: Optional[List[ChatSource]] = None
