"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SessionInfoTypedDict(TypedDict):
    success: NotRequired[bool]
    session_id: NotRequired[str]
    tenant_id: NotRequired[str]
    user_id: NotRequired[str]
    total_messages: NotRequired[int]
    user_messages: NotRequired[int]
    assistant_messages: NotRequired[int]
    other_messages: NotRequired[int]


class SessionInfo(BaseModel):
    success: Optional[bool] = None

    session_id: Optional[str] = None

    tenant_id: Optional[str] = None

    user_id: Optional[str] = None

    total_messages: Optional[int] = None

    user_messages: Optional[int] = None

    assistant_messages: Optional[int] = None

    other_messages: Optional[int] = None
