"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ChatRequestAction = Literal[
    "analytics",
    "chat",
    "onboarding",
    "relationship_modification",
    "graph_modification",
]
r"""Action type"""


class ChatRequestTypedDict(TypedDict):
    action: ChatRequestAction
    r"""Action type"""
    query: str
    r"""The chat query or question to send to the assistant"""
    session_id: str
    r"""Session ID to associate the message with"""


class ChatRequest(BaseModel):
    action: ChatRequestAction
    r"""Action type"""

    query: str
    r"""The chat query or question to send to the assistant"""

    session_id: str
    r"""Session ID to associate the message with"""
