"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from fermisdk.utils import FieldMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListSessionsRequestTypedDict(TypedDict):
    conversation_type: NotRequired[str]
    r"""Conversation type to list (e.g., 'chat', 'analytics', 'workflow')"""
    limit: NotRequired[int]
    r"""Maximum number of sessions to return. Omit to return all."""
    offset: NotRequired[int]
    r"""Number of sessions to skip for pagination"""


class ListSessionsRequest(BaseModel):
    conversation_type: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = "chat"
    r"""Conversation type to list (e.g., 'chat', 'analytics', 'workflow')"""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Maximum number of sessions to return. Omit to return all."""

    offset: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0
    r"""Number of sessions to skip for pagination"""
