"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectSessionResponseTypedDict(TypedDict):
    session_token: NotRequired[str]
    r"""Session token for OAuth flow"""
    connect_url: NotRequired[str]
    r"""OAuth connection URL"""
    success: NotRequired[bool]
    r"""Success status"""
    connection_id: NotRequired[str]
    r"""Connection ID"""
    message: NotRequired[str]
    r"""Response message"""


class ConnectSessionResponse(BaseModel):
    session_token: Annotated[Optional[str], pydantic.Field(alias="sessionToken")] = None
    r"""Session token for OAuth flow"""

    connect_url: Annotated[Optional[str], pydantic.Field(alias="connectUrl")] = None
    r"""OAuth connection URL"""

    success: Optional[bool] = None
    r"""Success status"""

    connection_id: Annotated[Optional[str], pydantic.Field(alias="connectionId")] = None
    r"""Connection ID"""

    message: Optional[str] = None
    r"""Response message"""
