"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from fermisdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ConnectionMetadataTypedDict(TypedDict):
    pass


class ConnectionMetadata(BaseModel):
    pass


class ConnectionTypedDict(TypedDict):
    id: NotRequired[int]
    connection_id: NotRequired[str]
    provider_config_key: NotRequired[str]
    created_at: NotRequired[datetime]
    metadata: NotRequired[ConnectionMetadataTypedDict]


class Connection(BaseModel):
    id: Optional[int] = None

    connection_id: Optional[str] = None

    provider_config_key: Optional[str] = None

    created_at: Optional[datetime] = None

    metadata: Optional[ConnectionMetadata] = None
