"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ConnectionMetadataResponseMetadataTypedDict(TypedDict):
    pass


class ConnectionMetadataResponseMetadata(BaseModel):
    pass


class ConnectionMetadataResponseTypedDict(TypedDict):
    success: NotRequired[bool]
    message: NotRequired[str]
    metadata: NotRequired[ConnectionMetadataResponseMetadataTypedDict]


class ConnectionMetadataResponse(BaseModel):
    success: Optional[bool] = None

    message: Optional[str] = None

    metadata: Optional[ConnectionMetadataResponseMetadata] = None
