"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
from fermisdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetSessionInfoRequestTypedDict(TypedDict):
    session_id: str
    r"""Session identifier"""


class GetSessionInfoRequest(BaseModel):
    session_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Session identifier"""
