"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class SyncEnqueueRequestTypedDict(TypedDict):
    connection_id: str
    provider_key: str


class SyncEnqueueRequest(BaseModel):
    connection_id: Annotated[str, pydantic.Field(alias="connectionId")]

    provider_key: Annotated[str, pydantic.Field(alias="providerKey")]
