"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .visualizationresponsejson import (
    VisualizationResponseJSON,
    VisualizationResponseJSONTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


PerformVisualizationResponseTypedDict = TypeAliasType(
    "PerformVisualizationResponseTypedDict",
    Union[VisualizationResponseJSONTypedDict, str],
)


PerformVisualizationResponse = TypeAliasType(
    "PerformVisualizationResponse", Union[VisualizationResponseJSON, str]
)
