"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from fermisdk.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SyncEnqueueResponseTypedDict(TypedDict):
    success: NotRequired[bool]
    sync_id: NotRequired[str]
    message: NotRequired[str]


class SyncEnqueueResponse(BaseModel):
    success: Optional[bool] = None

    sync_id: Annotated[Optional[str], pydantic.Field(alias="syncId")] = None

    message: Optional[str] = None
